#[non_exhaustive]pub enum AssetError {
InvalidPath,
NotFound,
}Expand description
Error returned by get when an asset path cannot be served.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidPath
The path is not a valid /sf-relative asset path.
NotFound
The path is valid but no embedded asset exists at that location.